@@ -44,6 +44,21 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
 
     return validated_date_list
 
+def clean_dataframe(df):
+    #
+    df = df.dropna(subset=['EVENT_TIME'])
+    df.reset_index(inplace=True, drop=True)
+    #
+    dropped_rows = []
+    for idx in df.index:
+        local_time_str = df["EVENT_TIME"][idx]
+        if 'unknown time' in local_time_str:
+            dropped_rows.append(idx)
+    df = df.drop(dropped_rows)
+
+    df.reset_index(inplace=True, drop=True)
+    return df
+
 def combine_intermediate_file(intermediate_participant_path, date_in_study):
     df_logs_combined = pd.DataFrame()
     participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
@@ -72,10 +87,9 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     # filter out irrelevant logs
     df_logs_combined = df_logs_combined[df_logs_combined['APP_EVENT'].isin(["KEYGUARD_HIDDEN", "KEYGUARD_SHOWN"])]
     df_logs_combined.reset_index(inplace=True, drop=True)
+    df_logs_combined = clean_dataframe(df_logs_combined)
 
     converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
-    df_logs_combined = df_logs_combined.dropna(subset=['EVENT_TIME'])
-    df_logs_combined.reset_index(inplace=True, drop=True)
     df_logs_combined["EVENT_TIME"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
                                          list(df_logs_combined["EVENT_TIME"])]
 
